@@ -4,7 +4,8 @@ import typing as t
 import click
 
 from aprsd import config as aprsd_config
-from aprsd import log
+from aprsd.logging import log
+from aprsd.utils import trace
 
 
 F = t.TypeVar("F", bound=t.Callable[..., t.Any])
@@ -55,9 +56,12 @@ def process_standard_options(f: F) -> F:
         ctx.obj["quiet"] = kwargs["quiet"]
         ctx.obj["config"] = aprsd_config.parse_config(kwargs["config_file"])
         log.setup_logging(
-            ctx.obj["config"], ctx.obj["loglevel"],
+            ctx.obj["config"],
+            ctx.obj["loglevel"],
             ctx.obj["quiet"],
         )
+        if ctx.obj["config"]["aprsd"].get("trace", False):
+            trace.setup_tracing(["method", "api"])
 
         del kwargs["loglevel"]
         del kwargs["config_file"]
