@@ -5,8 +5,10 @@ import time
 import aprslib
 from aprslib.exceptions import LoginError
 
-from aprsd import trace
+from aprsd import config as aprsd_config
+from aprsd import exception
 from aprsd.clients import aprsis, kiss
+from aprsd.utils import trace
 
 
 LOG = logging.getLogger("APRSD")
@@ -50,7 +52,8 @@ class Client:
 
     def reset(self):
         """Call this to force a rebuild/reconnect."""
-        del self._client
+        if self._client:
+            del self._client
 
     @abc.abstractmethod
     def setup_connection(self):
@@ -76,7 +79,21 @@ class APRSISClient(Client):
     @staticmethod
     def is_enabled(config):
         # Defaults to True if the enabled flag is non existent
-        return config["aprs"].get("enabled", True)
+        try:
+            return config["aprs"].get("enabled", True)
+        except KeyError:
+            return False
+
+    @staticmethod
+    def is_configured(config):
+        if APRSISClient.is_enabled(config):
+            # Ensure that the config vars are correctly set
+            config.check_option("aprs.login")
+            config.check_option("aprs.password")
+            config.check_option("aprs.host")
+            return True
+
+        return True
 
     @staticmethod
     def transport(config):
@@ -114,6 +131,7 @@ class APRSISClient(Client):
                 backoff = backoff * 2
                 continue
         LOG.debug(f"Logging in to APRS-IS with user '{user}'")
+        self._client = aprs_client
         return aprs_client
 
 
@@ -133,6 +151,26 @@ class KISSClient(Client):
 
         return False
 
+    @staticmethod
+    def is_configured(config):
+        # Ensure that the config vars are correctly set
+        if KISSClient.is_enabled(config):
+            config.check_option(
+                "aprsd.callsign",
+                default_fail=aprsd_config.DEFAULT_CONFIG_DICT["aprsd"]["callsign"],
+            )
+            transport = KISSClient.transport(config)
+            if transport == TRANSPORT_SERIALKISS:
+                config.check_option("kiss.serial")
+                config.check_option("kiss.serial.device")
+            elif transport == TRANSPORT_TCPKISS:
+                config.check_option("kiss.tcp")
+                config.check_option("kiss.tcp.host")
+                config.check_option("kiss.tcp.port")
+
+            return True
+        return True
+
     @staticmethod
     def transport(config):
         if config.get("kiss.serial.enabled", default=False):
@@ -157,8 +195,8 @@ class KISSClient(Client):
 
     @trace.trace
     def setup_connection(self):
-        ax25client = kiss.Aioax25Client(self.config)
-        return ax25client
+        client = kiss.KISS3Client(self.config)
+        return client
 
 
 class ClientFactory:
@@ -185,7 +223,7 @@ class ClientFactory:
             elif KISSClient.is_enabled(self.config):
                 key = KISSClient.transport(self.config)
 
-        LOG.debug(f"GET client {key}")
+        LOG.debug(f"GET client '{key}'")
         builder = self._builders.get(key)
         if not builder:
             raise ValueError(key)
@@ -195,7 +233,26 @@ class ClientFactory:
         """Make sure at least one client is enabled."""
         enabled = False
         for key in self._builders.keys():
-            enabled |= self._builders[key].is_enabled(self.config)
+            try:
+                enabled |= self._builders[key].is_enabled(self.config)
+            except KeyError:
+                pass
+
+        return enabled
+
+    def is_client_configured(self):
+        enabled = False
+        for key in self._builders.keys():
+            try:
+                enabled |= self._builders[key].is_configured(self.config)
+            except KeyError:
+                pass
+            except exception.MissingConfigOptionException as ex:
+                LOG.error(ex.message)
+                return False
+            except exception.ConfigOptionBogusDefaultException as ex:
+                LOG.error(ex.message)
+                return False
 
         return enabled
 
