@@ -7,10 +7,11 @@ import click
 import aprsd
 from aprsd import (
     cli_helper, client, flask, messaging, packets, plugin, stats, threads,
-    trace, utils,
+    utils,
 )
 from aprsd import aprsd as aprsd_main
 from aprsd.aprsd import cli
+from aprsd.threads import rx
 
 
 LOG = logging.getLogger("APRSD")
@@ -58,8 +59,6 @@ def server(ctx, flush):
         else:
             LOG.info(f"{x} = {flat_config[x]}")
 
-    if config["aprsd"].get("trace", False):
-        trace.setup_tracing(["method", "api"])
     stats.APRSDStats(config)
 
     # Initialize the client factory and create
@@ -70,6 +69,10 @@ def server(ctx, flush):
         LOG.error("No Clients are enabled in config.")
         sys.exit(-1)
 
+    if not client.factory.is_client_configured():
+        LOG.error("APRS client is not properly configured in config file.")
+        sys.exit(-1)
+
     # Creates the client object
     LOG.info("Creating client connection")
     client.factory.create().client
@@ -93,7 +96,7 @@ def server(ctx, flush):
     plugin_manager = plugin.PluginManager(config)
     plugin_manager.setup_plugins()
 
-    rx_thread = threads.APRSDRXThread(
+    rx_thread = rx.APRSDPluginRXThread(
         msg_queues=threads.msg_queues,
         config=config,
     )
@@ -111,6 +114,7 @@ def server(ctx, flush):
         (socketio, app) = flask.init_flask(config, loglevel, quiet)
         socketio.run(
             app,
+            allow_unsafe_werkzeug=True,
             host=config["aprsd"]["web"]["host"],
             port=config["aprsd"]["web"]["port"],
         )
