@@ -18,9 +18,10 @@ from werkzeug.security import check_password_hash, generate_password_hash
 import aprsd
 from aprsd import client
 from aprsd import config as aprsd_config
-from aprsd import log, messaging, packets, plugin, stats, threads, utils
+from aprsd import messaging, packets, plugin, stats, threads, utils
 from aprsd.clients import aprsis
-from aprsd.logging import logging as aprsd_logging
+from aprsd.logging import log
+from aprsd.logging import rich as aprsd_logging
 
 
 LOG = logging.getLogger("APRSD")
@@ -600,8 +601,8 @@ def init_flask(config, loglevel, quiet):
     flask_app = flask.Flask(
         "aprsd",
         static_url_path="/static",
-        static_folder="web/static",
-        template_folder="web/templates",
+        static_folder="web/admin/static",
+        template_folder="web/admin/templates",
     )
     setup_logging(config, flask_app, loglevel, quiet)
     server = APRSDFlask()
