@@ -11,18 +11,23 @@ cat << EOF
 usage: $0 options
 
 OPTIONS:
+   -h      Show help
    -t      The tag/version (${TAG}) (default = master)
    -d      Use Dockerfile-dev for a git clone build
+   -b      Branch to use (default = master)
+   -r      Destroy and rebuild the buildx environment
 EOF
 }
 
 
 ALL_PLATFORMS=0
 DEV=0
+REBUILD_BUILDX=0
 TAG="latest"
-BRANCH="master"
+BRANCH=${BRANCH:-master}
+VERSION="2.6.0"
 
-while getopts “t:dab:” OPTION
+while getopts “hdart:b:v:” OPTION
 do
     case $OPTION in
         t)
@@ -34,17 +39,26 @@ do
         a)
            ALL_PLATFORMS=1
            ;;
+        r)
+           REBUILD_BUILDX=1
+           ;;
         d)
            DEV=1
            ;;
+        v)
+           VERSION=$OPTARG
+           ;;
+        h)
+           usage
+           exit 0
+           ;;
         ?)
            usage
-           exit
+           exit -1
            ;;
     esac
 done
 
-VERSION="2.5.8"
 
 if [ $ALL_PLATFORMS -eq 1 ]
 then
@@ -54,15 +68,19 @@ else
     PLATFORMS="linux/amd64"
 fi
 
-echo "Build with tag=${TAG} BRANCH=${BRANCH} dev?=${DEV} platforms?=${PLATFORMS}"
 
 
-echo "Destroying old multiarch build container"
-docker buildx rm multiarch
-docker run --rm --privileged multiarch/qemu-user-static --reset -p yes
-echo "Creating new buildx container"
-docker buildx create --name multiarch --driver docker-container --use --platform linux/arm/v7,linux/arm/v6,linux/arm64,linux/amd64 --config ./buildkit.toml --use --driver-opt image=moby/buildkit:master
-docker buildx inspect --bootstrap
+if [ $REBUILD_BUILDX -eq 1 ]
+then
+    echo "Destroying old multiarch build container"
+    docker buildx rm multiarch
+    docker run --rm --privileged multiarch/qemu-user-static --reset -p yes
+    echo "Creating new buildx container"
+    docker buildx create --name multiarch --driver docker-container --use \
+        --config ./buildkit.toml --use \
+        --driver-opt image=moby/buildkit:master
+    docker buildx inspect --bootstrap
+fi
 
 if [ $DEV -eq 1 ]
 then
@@ -70,17 +88,17 @@ then
     # Use this script to locally build the docker image
     docker buildx build --push --platform $PLATFORMS \
         -t harbor.hemna.com/hemna6969/aprsd:$TAG \
-        -f Dockerfile-dev --build-arg branch=$BRANCH --no-cache .
+        -f Dockerfile-dev --build-arg branch=$BRANCH \
+        --build-arg BUILDX_QEMU_ENV=true \
+        --no-cache .
 else
     # Use this script to locally build the docker image
-    echo "Build with tag=${TAG} BRANCH=${BRANCH} platforms?=${PLATFORMS}"
+    echo "Build with tag=${TAG} BRANCH=${BRANCH} dev?=${DEV} platforms?=${PLATFORMS} VERSION=${VERSION}"
     docker buildx build --push --platform $PLATFORMS \
-        --allow security.insecure \
+        --build-arg VERSION=$VERSION \
+        --build-arg BUILDX_QEMU_ENV=true \
         -t hemna6969/aprsd:$VERSION \
         -t hemna6969/aprsd:$TAG \
         -t hemna6969/aprsd:latest \
-        -t harbor.hemna.com/hemna6969/aprsd:$TAG \
-        -t harbor.hemna.com/hemna6969/aprsd:$VERSION \
-        -t harbor.hemna.com/hemna6969/aprsd:latest \
         -f Dockerfile .
 fi
